#ifndef _BSS_QRCODE_READER_H_
#define _BSS_QRCODE_READER_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_QR_DLL)
#if defined(_BSS_QR_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes 
*/

#define BSS_QR_OK               (0)
#define BSS_QR_NOTFOUND         (1)
#define BSS_QR_INVALIDARGS      (2)
#define BSS_QR_OUTOFMEMORY      (3)
#define BSS_QR_BADSYMBOL        (4)


/* 
// Structure for general barcode information
*/
typedef struct BSS_QRCodeInfo_Struct
{
    int                 nCenterPosX;           /* Center (X) barcode position on the image    */
    int                 nCenterPosY;           /* Center (Y) barcode position on the image    */
    int                 nDataLength;           /* Length of barcode's data (in bytes)         */
    char*               pchData;               /* Pointer to barcode's data                   */
} bssQRCodeInfo;


/* 
// Read QRCode barcode symbol on the image
*/
BSS_DLL int BSS_ReadQRCode
(
    const unsigned char* pImageData,           /* Pointer to image data                       */
    int                  nImageWidth,          /* The image width                             */
    int                  nImageHeight,         /* The image height                            */
    int                  nImageRowDist,        /* Distance between image's rows (in bytes)    */
    int                  nTryReadMultiple,     /* Try to read multiple barcodes on the image  */
    bssQRCodeInfo**      ppQRCodeInfo,         /* Pointer to array with barcodes' information */
    int*                 pnQRCodeInfoCount     /* Pointer to number of recognized symbol(s)   */
);

/* 
// Release allocated resources 
*/
BSS_DLL int BSS_ReleaseQRCodeResults
(
    bssQRCodeInfo*       pQRCodeInfo,          /* Pointer to array with barcodes' information */
    int                  nQRCodeInfoCount      /* Number of items in the array                */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_QRCODE_READER_H_ */
